@@ -2,25 +2,28 @@ from zpipe.utils.ztypes import *
 from zpipe.stages.worker_stage import WorkerStage
 
 class Pipeline():
-    def __init__(self, port_base, max_ports):
+    def __init__(self, pipe_id):
         self.stages = []
-        self.port_base = port_base
-        self.max_ports = max_ports
-        self.cur_ports = 0
+        self.pipe_id = pipe_id
+        self.num_stages = 0
 
 
     def add_stage(self, stage):
+        """
+        Arguments
+            stage: stage to add
+        Return
+            num_stages: the number of current stages in this pipeline
+        """
+        self.num_stages += 1
         if stage.stage_type is not DST:
-            if self.cur_ports >= self.max_ports:
-                print("Pipeline port is full")
-                return
-            stage.set_outlink(self.port_base + self.cur_ports)
-            self.cur_ports+=1
+            stage.set_outlink(self.pipe_id)
 
         if stage.__class__ == WorkerStage:
             stage.worker_cls.make(stage.cls_args, stage.in_queue, stage.out_queue,
                                   stage.worker_num, stage.stage_type)
         self.stages.append(stage)
+        return self.num_stages
 
 
     def link_stages(self, src, dst, dependency, arg_pos, conflate):
@@ -33,12 +36,9 @@ class Pipeline():
         if src.otype not in dst.itypes:
             print("dst itypes don't include src otype")
             return
-        if self.cur_ports >= self.max_ports:
-            print("Pipeline link ports are full")
-            return
 
-        print("listen to ", src.outlink_port, " by ", dst.stage_type)
-        dst.add_inlink(port=src.outlink_port, dependency=dependency, arg_pos=arg_pos, conflate=conflate)
+        print("listen to ", src.outlink_id, " by ", dst.stage_type)
+        dst.add_inlink(inlink_id=src.outlink_id, dependency=dependency, arg_pos=arg_pos, conflate=conflate)
 
 
     def start(self):
@@ -57,4 +57,4 @@ class Pipeline():
 
     def terminate(self):
         for stage in self.stages:
-            stage.terminate()
\ No newline at end of file
+            stage.terminate()
