@@ -10,4 +10,9 @@ PAUSED = 'PAUSED'
 
 # Inlink Detail: dep_and_pos
 DEPENDENCY = 0
-POSITION = 1
\ No newline at end of file
+POSITION = 1
+CONFLATE = 2
+
+# link types
+PYOBJ = 'PYOBJ'
+BYTES = 'BYTES'
\ No newline at end of file
